@@ -8,7 +8,7 @@ master_doc = "index"
 # Custom sidebar templates, maps document names to template names.
 html_theme = 'alabaster'
 templates_path = ['_templates']
-html_sidebars = {'index': 'tidelift-sidebar.html'}
+html_sidebars = {'index': ['tidelift-sidebar.html']}
 
 link_files = {
     '../CHANGES.rst': dict(
